@@ -29,10 +29,11 @@ Released under the MIT licence.
 __author__ = "Marius Gedminas (marius@gedmin.as)"
 __copyright__ = "Copyright (c) 2008-2011 Marius Gedminas"
 __license__ = "MIT"
-__version__ = "1.7.0"
-__date__ = "2011-03-11"
+__version__ = "1.7.1"
+__date__ = "2011-12-11"
 
 
+import codecs
 import gc
 import re
 import inspect
@@ -508,11 +509,16 @@ def show_graph(objs, edge_func, swap_source_target,
     if not isinstance(objs, (list, tuple)):
         objs = [objs]
     if filename and filename.endswith('.dot'):
-        f = open(filename, 'w')
+        f = codecs.open(filename, 'w', encoding='utf-8')
         dot_filename = filename
     else:
         fd, dot_filename = tempfile.mkstemp('.dot', text=True)
         f = os.fdopen(fd, "w")
+        if f.encoding != None:
+            # Python 3 will wrap the file in the user's preferred encoding
+            # Re-wrap it for utf-8
+            import io
+            f = io.TextIOWrapper(f.detach(), 'utf-8')
     f.write('digraph ObjectGraph {\n'
             '  node[shape=box, style=filled, fillcolor=white];\n')
     queue = []
@@ -737,5 +743,6 @@ is_identifier = re.compile('[a-zA-Z_][a-zA-Z_0-9]*$').match
 def program_in_path(program):
     path = os.environ.get("PATH", os.defpath).split(os.pathsep)
     path = [os.path.join(dir, program) for dir in path]
-    path = [True for file in path if os.path.isfile(file)]
+    path = [True for file in path
+            if os.path.isfile(file) or os.path.isfile(file + '.exe')]
     return bool(path)
